@@ -182,7 +182,7 @@ process_line (char     *line,
 static void
 fr_command_unstuff_list (FRCommand *comm)
 {
-	char *arg, *path, *template;
+	char *arg, *path;
 	char *filename;
 	char *path_dots;
 
@@ -194,9 +194,7 @@ fr_command_unstuff_list (FRCommand *comm)
 	fr_process_add_arg (comm->process, "--trace");
 
 	/* Actually unpack everything in a temporary directory */
-	template = g_strdup_printf ("%s/file-roller-unstuffXXXXXX",
-			g_get_tmp_dir ());
-	path = mkdtemp (template);
+	path = get_temp_work_dir ();
 	path_dots = unstuff_is_shit_with_filenames (path);
 	g_free (path);
 
@@ -322,7 +320,7 @@ fr_command_unstuff_finalize (GObject *object)
 GType
 fr_command_unstuff_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
