@@ -104,7 +104,6 @@ int main (int argc, char **argv)
                                       GNOME_PARAM_APP_SYSCONFDIR, FR_SYSCONFDIR,
                                       GNOME_PARAM_APP_DATADIR, FR_DATADIR,
                                       GNOME_PARAM_APP_LIBDIR, FR_LIBDIR,
-
 				      NULL);
 
 	g_object_get_property (G_OBJECT (program),
@@ -351,7 +350,19 @@ prepare_app (poptContext pctx)
 	} 
 
 	default_dir = get_path_from_url (default_url);
-	extract_to_path = get_path_from_url (extract_to);
+	
+	if ((extract_to != NULL) && g_path_is_absolute (extract_to))
+		extract_to_path = get_path_from_url (extract_to);
+	else {
+		char *full_path;
+		char *current_dir = g_get_current_dir ();
+
+		full_path = g_build_filename (current_dir, extract_to, NULL);
+		g_free (current_dir);
+		extract_to_path = get_path_from_url (full_path);
+		g_free (full_path);
+	}
+
         add_to_path = get_path_from_url (add_to);
 
 	if ((add_to != NULL) || (add == 1)) { /* Add files to an archive */
@@ -362,7 +373,7 @@ prepare_app (poptContext pctx)
 		window = window_new ();
 		if (default_dir != NULL)
 			window_set_default_dir (window, default_dir);
-		gtk_widget_show (window->app);
+		/*gtk_widget_show (window->app);*/
 		
 		while ((filename = poptGetArg (pctx)) != NULL) {
 			char *path;
@@ -392,7 +403,7 @@ prepare_app (poptContext pctx)
 		window = window_new ();
 		if (default_dir != NULL)
 			window_set_default_dir (window, default_dir);
-		gtk_widget_show (window->app);
+		/*gtk_widget_show (window->app);*/
 		
 		while ((archive = poptGetArg (pctx)) != NULL) 
 			window_archive__open_extract (window, 
@@ -443,12 +454,13 @@ save_session (GnomeClient *client)
 		FRWindow *window = scan->data;
 		char     *key;
 
+		key = g_strdup_printf ("Session/archive%d", i);
+
 		if ((window->archive == NULL) 
 		    || (window->archive->filename == NULL))
-			continue;
-
-		key = g_strdup_printf ("Session/archive%d", i);
-		gnome_config_set_string (key, window->archive->filename);
+			gnome_config_set_string (key, "");
+		else
+			gnome_config_set_string (key, window->archive->filename);
 		g_free (key);
 
 		i++;
@@ -561,7 +573,8 @@ load_session (void)
 
 		window = window_new ();
 		gtk_widget_show (window->app);
-		window_archive_open (window, filename, GTK_WINDOW (window->app));
+		if (strlen (filename) != 0)
+			window_archive_open (window, filename, GTK_WINDOW (window->app));
 
 		g_free (filename);
 	}
